import React, { useState, useEffect } from 'react';
import { Form, Input, Button, Icon, Select, message, Table, Divider, Tag, Pagination, Modal, DatePicker, InputNumber, Checkbox, Row, Col } from 'antd';
import { FormattedMessage } from 'umi-plugin-react/locale';
import router from 'umi/router';
import moment from 'moment';
import apis from '../../../services/apis';
import request from '../../../utils/request';
import AuthButton from '@/components/AuthButton';
import ImageUploader from '../../../components/XForm/ImageUpload';

const { Option } = Select;
const { MonthPicker, RangePicker, WeekPicker } = DatePicker;


const header = props => {
    const sampleId = props.location.query.id;
    // const sampleName = props.location.query.sampleName;
    // const [sampleData, setSampleData] = useState({})

    //   useEffect(() => {
    //     getSampleData(sampleId);
    //   },[])

    //   // 查询列表
    //   const getSampleData = (demandId) => {
    //       request({ ...apis.taH5SampleManager.taH5DemandById, urlData: {id: demandId} }).then((data) => {
    //           setDemandData(data)
    //           props.form.setFieldsValue(data)
    //       })
    //   }

    // 跳转到编辑
    const toDetail = rowData => () => {
        if (rowData) {
            router.push({
                pathname: '/h5SampleManager/h5Demand/edit',
                query: {
                    id: demandId,
                },
            });
            return
        }
    }

    function handleSubmit(e) {
        e.preventDefault();
        props.form.validateFields((err, values) => {
            if (!err) {
                values.h5SampleId = sampleId
                values.endDate = moment(values.endDate._d).format('YYYY-MM-DD HH:mm:ss')
                values.isMiniapp = 1
                values.fromH5Sample = true
                request({ ...apis.activity.addtaDrainage, data: { ...values } }).then(data => {
                    message.info('操作成功')

                }).catch(err => {
                    message.error(err.msg || err.message)
                })

                // values.sampleName = sampleName
                // request({ ...apis.taH5SampleManager.addTaH5Demand, data: { ...values } }).then(() => {
                //     message.info('保存成功')
                //     // router.go(-1);
                // }).catch((err) => {
                //     message.info(err.msg || err.message)
                // })
            }
        });
    }

    const { getFieldDecorator } = props.form;

    return (
        <>
            <Form labelCol={{ span: 7 }} wrapperCol={{ span: 12 }} onSubmit={handleSubmit}>
                <Form.Item label="H5活动名称">
                    {getFieldDecorator('name', {
                        rules: [
                            {
                                required: true,
                                message: '请填写活动名称',
                            },
                        ],
                    })(<Input placeholder="H5活动名称" />)}
                </Form.Item>
                <Form.Item label="下架时间">
                    {getFieldDecorator('endDate', {
                        // initialValue: formsdate.endDate ? moment(formsdate.endDate, 'YYYY-MM-DD HH:mm:ss') : null,
                        rules: [
                            { required: true, message: '请输入下架时间' },
                        ]
                    })(
                        <DatePicker
                            showTime={{ format: 'HH:mm:ss' }}
                        />,
                    )}
                </Form.Item>
                <Form.Item label="分享设置" help="建议图片尺寸：750*600px，比例5:4,格式：jpg">
                    {getFieldDecorator('shareImg', {
                        // initialValue: formsDate.shareImg,
                        rules: [
                            { required: true, message: '请选择分享图片' },
                        ]
                    })(<ImageUploader />)}
                </Form.Item>
                <Form.Item label="活动分享语">
                    {getFieldDecorator('shareTitle', {
                        // initialValue: formsDate.shareTitle,
                        rules: [
                            { required: true, message: '请输入活动分享语' },
                        ]
                    })(
                        <Input
                            placeholder="分享语，不超过15个字"
                            maxLength="15"
                        />,
                    )}
                </Form.Item>
                <Form.Item label="中间页飞机图" help="建议图片尺寸：750*1667px，比例9:20,格式：jpg。图片底部不要放置关键信息。">
                    {getFieldDecorator('middleImg', {
                        // initialValue: formsDate.middleImg,
                        rules: [
                            { required: true, message: '请选择中间页飞机图' },
                        ]
                    })(<ImageUploader />)}
                </Form.Item>
                <Form.Item style={{ width: '400px', margin: 'auto', display: 'flex', justifyContent: 'space-between' }}>
                    <Button type="primary" htmlType="submit">保存</Button>
            &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
            <Button onClick={() => router.go(-1)}>取消</Button>
                </Form.Item>
            </Form>
        </>
    )
}

const WrappedHeader = Form.create({ name: 'header' })(header);

export default WrappedHeader
